@@ -17,16 +17,17 @@ class BaseStage:
     async def run_with_time_report(self, *args, **kwargs):
         start = time.ctime(int(time.time()))
         workflow_config = self.workflow.config
-        getattr(workflow_config, self.name)
-        workflow_config.set_stage(
-            self.name,
-            {
-                BaseStage.START: start,
-                BaseStage.END: None,
-                BaseStage.REPORT: None,
-            },
-        )
-        workflow_config.save()
+        status = getattr(workflow_config, self.name)
+        if status is None:
+            workflow_config.set_stage(
+                self.name,
+                {
+                    BaseStage.START: start,
+                    BaseStage.END: None,
+                    BaseStage.REPORT: None,
+                },
+            )
+            workflow_config.save()
 
         report = await self.run(*args, **kwargs)
         end = time.ctime(int(time.time()))
