@@ -30,9 +30,7 @@ class EvalStage(BaseStage):
         self.stage_dir = os.path.join(workflow_dir, EvalStage.DIR)
 
         if os.path.isdir(self.stage_dir):
-            raise Exception("Stage directory already exists.")
-
-        os.mkdir(self.stage_dir)
+            os.mkdir(self.stage_dir)
 
         name = config.translation_model["name"]
         args = config.translation_model["args_decoding"]
@@ -126,7 +124,7 @@ class EvalStage(BaseStage):
         return tgt_tokenizer
 
     async def eval_files(
-        self, gpu: int, step: int, src_path: str, ref_path: str
+        self, gpu: int, step: int, src_path: str, ref_path: str, out_name: str
     ):
         print("Loading model")
         config = self.workflow.project.config.config_dict
@@ -137,10 +135,8 @@ class EvalStage(BaseStage):
         self.stage_dir = os.path.join(workflow_dir, EvalStage.DIR)
         self._prepare_dir = os.path.join(workflow_dir, "02_prepared")
 
-        if os.path.isdir(self.stage_dir):
-            raise Exception("Stage directory already exists.")
-
-        os.mkdir(self.stage_dir)
+        if not os.path.isdir(self.stage_dir):
+            os.mkdir(self.stage_dir)
 
         model_dir = os.path.join(workflow_dir, "03_trained")
         model_path = None
@@ -160,7 +156,10 @@ class EvalStage(BaseStage):
             "gpu": True if gpu is not None else False
         }
         engine = Engine(config)
-        out_path = os.path.join(self.stage_dir, "test_output.txt")
+        if out_name is not None:
+            out_path = os.path.join(self.stage_dir, out_name)
+        else:
+            out_path = os.path.join(self.stage_dir, "test_output.txt")
 
         with open(src_path, "r") as src_file, open(out_path, "w") as out_file:
             async def _write_to_file(batch):
